@@ -4,19 +4,19 @@
 import pathlib
 import shutil
 import pytest
-pytestmark = [pytest.mark.asyncio,
+pytestmark = [pytest.mark.asyncio(scope="session"),
               pytest.mark.skipif(shutil.which("pacman") is None,
                                  reason="requires pacman command"),
               pytest.mark.skipif(not pathlib.Path("/var/lib/pacman/sync/core.db").exists(),
                                  reason="requires synced pacman databases")]
 
 async def test_pacman(get_version):
-    assert await get_version("ipw2100-fw", {
+    assert await get_version("base", {
         "source": "pacman",
-    }) == "1.3-10"
+    }) == "3-2"
 
 async def test_pacman_strip_release(get_version):
-    assert await get_version("ipw2100-fw", {
+    assert await get_version("base", {
         "source": "pacman",
         "strip_release": 1,
-    }) == "1.3"
+    }) == "3"
