@@ -1,19 +1,18 @@
 # MIT licensed
 # Copyright (c) 2019-2020 lilydjwg <lilydjwg@gmail.com>, et al.
 
-from flaky import flaky
 import pytest
 pytestmark = [pytest.mark.asyncio(scope="session"),
               pytest.mark.needs_net]
 
-@flaky(max_runs=10)
+@pytest.mark.flaky(reruns=10)
 async def test_repology(get_version):
   assert await get_version("ssed", {
         "source": "repology",
         "repo": "aur",
   }) == "3.62"
 
-@flaky(max_runs=10)
+@pytest.mark.flaky(reruns=10)
 async def test_repology_subrepo(get_version):
   assert await get_version("asciiquarium", {
         "source": "repology",
