@@ -1,5 +1,5 @@
 # MIT licensed
-# Copyright (c) 2020 lilydjwg <lilydjwg@gmail.com>, et al.
+# Copyright (c) 2020,2024 lilydjwg <lilydjwg@gmail.com>, et al.
 # Copyright (c) 2017 Felix Yan <felixonmars@archlinux.org>, et al.
 
 import pytest
@@ -7,9 +7,10 @@ pytestmark = [pytest.mark.asyncio(scope="session"), pytest.mark.needs_net]
 
 @pytest.mark.flaky
 async def test_ubuntupkg(get_version):
-    assert await get_version("sigrok-firmware-fx2lafw", {
+    v = await get_version("sigrok-firmware-fx2lafw", {
         "source": "ubuntupkg",
-    }) == "0.1.7-1"
+    })
+    assert v.startswith("0.1.7-")
 
 @pytest.mark.flaky
 async def test_ubuntupkg_strip_release(get_version):
